@@ -12,6 +12,7 @@ srcpath = os.path.dirname(os.path.realpath(__file__))+"/.."
 
 def pcall(fin,xs,batch_size=1,**kwargs):
     """Wrapper to allow for a batch size"""
+    #if batch_size==1: return pcall_killproof(fin,xs,**kwargs)
     if batch_size==1: return pcall_single(fin,xs,**kwargs)
     else: 
         nx = len(xs) # number of xs
@@ -24,17 +25,49 @@ def pcall(fin,xs,batch_size=1,**kwargs):
                 o = [] # reset
         def fnew(y): return [fin(x) for x in y] # call this batch
         outs = pcall_single(fnew,xsn,**kwargs) # call the inputs
+        #outs = pcall_killproof(fnew,xsn,**kwargs) # call the inputs
         out = []
         for o in outs: out += o # add
         return out
 
 
+def pcall_killproof_dict(fin,xs,info=True,**kwargs):
+    """Call method that is relaunched for killed jobs"""
+    outl = pcall_single(fin,xs,**kwargs) # the return is a list
+    out = dict()
+    for i in range(len(xs)):
+        out[xs[i]] = outl[i] # store
+    xsnew = [] # empty list
+    for (x,o) in zip(xs,out): # loop over keys
+        if out[o] is None: # this one has been killed/failed
+            if info: 
+                print("Relaunching",o)
+            xsnew.append(o) # store
+    if len(xsnew)==0: 
+        return out # all good
+    else:
+        out2 = pcall_killproof_dict(fin,xsnew,info=info,**kwargs) # new outputs
+        for o in out2:
+            out[o] = out2[o] # overwrite
+        return out
+
+def pcall_killproof(fin,xs,return_mode="list",**kwargs):
+    out = pcall_killproof_dict(fin,xs,**kwargs)
+    if return_mode=="list": 
+        return [out[x] for x in xs]
+    elif return_mode=="dict": 
+        return out
+
+
+
 def pcall_single(fin,xs,time=10,memory=5000,error=None,
+    constraint = None,
     return_mode="list"):
     """Run a parallel calculation with slurm"""
     n = len(xs) # number of calculations
     f = lambda x: fin(x)
     main = "import dill as pickle\nimport os\n"
+    main += "os.system('touch START')\n"
     main += "import sys ; sys.path.append('"+srcpath+"')\n"
     main += "try: ii = int(os.environ['SLURM_ARRAY_TASK_ID'])\n"
     main += "except: ii = 0\n"
@@ -64,6 +97,8 @@ def pcall_single(fin,xs,time=10,memory=5000,error=None,
     runsh = "#!/bin/bash\n#SBATCH -n 1\n#SBATCH -t "+str(int(time))+":"+str(mins)+":00\n"
     runsh += "#SBATCH --mem-per-cpu="+str(memory)+"\n"
     runsh += "#SBATCH --array=0-"+str(n-1)+"\n"
+    if constraint is not None:
+        runsh += "#SBATCH --constraint="+str(constraint)+"\n"
     runsh += "srun python run.py\n"
     open(pfolder+"/run.sh","w").write(runsh) # parallel file
     pwd = os.getcwd() # current directory 
@@ -79,14 +114,20 @@ def pcall_single(fin,xs,time=10,memory=5000,error=None,
     while True:
         finished = True
         for i in range(n):
-            if not path.exists(pfolder+"/folder_"+str(i)+"/DONE"):
-                finished = False
+            pfolderi = pfolder+"/folder_"+str(i)
+            if started_and_killed(pfolderi,str(job)+"_"+str(i)):
+                pass # ignore as if it finished
+            else:
+                if not path.exists(pfolderi+"/DONE"):
+                    finished = False
         if finished: break
+        # check if it has been killed
     # get all the data
     ys = []
     for i in range(n):
         folder = pfolder+"/folder_"+str(i)+"/"
-        y = pickle.load(open(folder+'out.obj','rb'))
+        try:  y = pickle.load(open(folder+'out.obj','rb'))
+        except: y = None # in case the fiel does not exist
         if y is None: y = error # use this as backup variable
         ys.append(y)
     if return_mode=="list": return ys
@@ -115,3 +156,20 @@ def jobkill(n):
     signal.signal(signal.SIGTERM, killf)
 
 
+
+def started_and_killed(inipath,number):
+    """Check if a certain job that was started has been killed"""
+    from os import path
+    if path.exists(inipath+"/START"): # the job started
+        out,err = subprocess.Popen(["squeue","-r"],
+                      stdout=subprocess.PIPE).communicate()
+        out = out.decode("utf-8").split("\n")
+        for o in out:
+            try:
+                if number in o:
+                    return False
+            except: pass
+        return True # the job was killed
+    else: return False # the job has not started
+
+
